package ipastushenko.training;

import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import javax.validation.Valid;

import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

/**
 * AccountController
 * @author Ivan Pastushenko
 * @version 1.0.0
 * Date: 07.09.2013
 */
@Controller
@RequestMapping(value="/account")
public class AccountController {
    private Map<Long, Account> accounts = new ConcurrentHashMap<>();

    @RequestMapping(method=RequestMethod.GET)
    public String getCreateForm(Model model) {
        model.addAttribute(new Account());
        return "account/createForm";
    }

    @RequestMapping(method=RequestMethod.POST)
    public String create(@Valid Account account, BindingResult result) {
        if (result.hasErrors()) {
            return "account/createForm";
        }
        this.accounts.put(account.assignId(), account);
        return "redirect:/account/" + account.getId();
    }

    @RequestMapping(value="{id}", method=RequestMethod.GET)
    public String getView(@PathVariable Long id, Model model) {
        Account account = this.accounts.get(id);
        if (account == null)
            throw new ResourceNotFoundException(id);
        model.addAttribute(account);
        return "account/view";
    }
}
